PCB Environment: dsn::Path Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
dsn::Path Struct Reference

## Public Member Functions
BBox | bbox () const
bool | operator== (const Path &) const
std::string | str (bool verbose=false) const

## Data Fields
double | aperture_width {0.0}
std::vector< double > | xy
int | z {-1}

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSN.hpp